API Reference
=============

Core I/O
--------

.. autofunction:: scitex_io.save
.. autofunction:: scitex_io.load

Registry
--------

.. autofunction:: scitex_io.register_saver
.. autofunction:: scitex_io.register_loader
.. autofunction:: scitex_io.get_saver
.. autofunction:: scitex_io.get_loader
.. autofunction:: scitex_io.list_formats
.. autofunction:: scitex_io.unregister_saver
.. autofunction:: scitex_io.unregister_loader

Explorers
---------

.. autoclass:: scitex_io.H5Explorer
   :members:

.. autoclass:: scitex_io.ZarrExplorer
   :members:
